@@ -6,15 +6,21 @@ from openapi_core.validation.request import (
 )
 from openapi_core.validation.request import openapi_request_security_validator
 from openapi_core.validation.request import openapi_request_validator
+from openapi_core.validation.request import openapi_v3_request_validator
+from openapi_core.validation.request import openapi_v30_request_validator
+from openapi_core.validation.request import openapi_v31_request_validator
 from openapi_core.validation.response import openapi_response_data_validator
 from openapi_core.validation.response import openapi_response_headers_validator
 from openapi_core.validation.response import openapi_response_validator
+from openapi_core.validation.response import openapi_v3_response_validator
+from openapi_core.validation.response import openapi_v30_response_validator
+from openapi_core.validation.response import openapi_v31_response_validator
 from openapi_core.validation.shortcuts import validate_request
 from openapi_core.validation.shortcuts import validate_response
 
 __author__ = "Artur Maciag"
 __email__ = "maciag.artur@gmail.com"
-__version__ = "0.16.3"
+__version__ = "0.16.6"
 __url__ = "https://github.com/p1c2u/openapi-core"
 __license__ = "BSD 3-Clause License"
 
@@ -22,10 +28,16 @@ __all__ = [
     "Spec",
     "validate_request",
     "validate_response",
+    "openapi_v3_request_validator",
+    "openapi_v30_request_validator",
+    "openapi_v31_request_validator",
     "openapi_request_body_validator",
     "openapi_request_parameters_validator",
     "openapi_request_security_validator",
     "openapi_request_validator",
+    "openapi_v3_response_validator",
+    "openapi_v30_response_validator",
+    "openapi_v31_response_validator",
     "openapi_response_data_validator",
     "openapi_response_headers_validator",
     "openapi_response_validator",
